@@ -1,9 +1,11 @@
 #pragma once
 
 #include <cmath>
+#include <map>
 #include <qualpal/color_difference.h>
 #include <qualpal/colors.h>
 #include <qualpal/matrix.h>
+#include <string>
 #include <vector>
 
 namespace qualpal {
@@ -14,6 +16,10 @@ farthestPoints(const std::size_t n,
                const metrics::MetricType& metric_type,
                const bool has_bg = false,
                const std::size_t n_fixed = 0,
-               const double max_memory = 1);
+               const double max_memory = 1,
+               const std::array<double, 3>& white_point = { 0.95047,
+                                                            1,
+                                                            1.08883 },
+               const std::map<std::string, double>& cvd = {});
 
 } // namespace qualpal
